ProSHADE: Member List

| ProSHADE 0.7.5.1 (JAN 2021) Protein Shape Detection

ProSHADE_settings Member List

This is the complete list of members for ProSHADE_settings, including all inherited members.

addExtraSpace | ProSHADE_settings |
addStructure(std::string structure) | ProSHADE_settings |
allDetectedCAxes | ProSHADE_settings |
allDetectedDAxes | ProSHADE_settings |
allDetectedIAxes | ProSHADE_settings |
allDetectedOAxes | ProSHADE_settings |
allDetectedTAxes | ProSHADE_settings |
axisErrTolerance | ProSHADE_settings |
axisErrToleranceDefault (defined in ProSHADE_settings) | ProSHADE_settings |
blurFactor | ProSHADE_settings |
boundsExtraSpace | ProSHADE_settings |
boundsSimilarityThreshold | ProSHADE_settings |
changeMapResolution | ProSHADE_settings |
changeMapResolutionTriLinear | ProSHADE_settings |
computeEnergyLevelsDesc | ProSHADE_settings |
computeRotationFuncDesc | ProSHADE_settings |
computeTraceSigmaDesc | ProSHADE_settings |
correlationKernel | ProSHADE_settings |
detectedSymmetry | ProSHADE_settings |
determineAllSHValues(proshade_unsign xDim, proshade_unsign yDim, proshade_unsign zDim) | ProSHADE_settings |
determineBandwidth(proshade_unsign circumference) | ProSHADE_settings |
determineBandwidthFromAngle(proshade_double uncertainty) | ProSHADE_settings |
determineIntegrationOrder(proshade_single maxMapRange) | ProSHADE_settings |
determineSphereDistances(proshade_single maxMapRange) | ProSHADE_settings |
enLevMatrixPowerWeight | ProSHADE_settings |
firstModelOnly | ProSHADE_settings |
forceBounds | ProSHADE_settings |
forceP1 | ProSHADE_settings |
getCommandLineParams(int argc, char **argv) | ProSHADE_settings |
halfMapKernel | ProSHADE_settings |
inputFiles | ProSHADE_settings |
integOrder | ProSHADE_settings |
invertMap | ProSHADE_settings |
maskFileName | ProSHADE_settings |
maskingThresholdIQRs | ProSHADE_settings |
maskMap | ProSHADE_settings |
maxBandwidth | ProSHADE_settings |
maxSphereDists | ProSHADE_settings |
maxSymmetryFold | ProSHADE_settings |
minSymPeak | ProSHADE_settings |
moveToCOM | ProSHADE_settings |
noIQRsFromMedianNaivePeak | ProSHADE_settings |
normaliseMap | ProSHADE_settings |
outName | ProSHADE_settings |
overlayStructureName | ProSHADE_settings |
pdbBFactorNewVal | ProSHADE_settings |
peakNeighbours | ProSHADE_settings |
printSettings(void) | ProSHADE_settings |
progressiveSphereMapping | ProSHADE_settings |
ProSHADE_settings(void) | ProSHADE_settings |
ProSHADE_settings(ProSHADE_Task task) | ProSHADE_settings |
reBoxMap | ProSHADE_settings |
recommendedSymmetryFold | ProSHADE_settings |
recommendedSymmetryType | ProSHADE_settings |
removeWaters | ProSHADE_settings |
requestedResolution | ProSHADE_settings |
requestedSymmetryFold | ProSHADE_settings |
requestedSymmetryType | ProSHADE_settings |
rotationUncertainty | ProSHADE_settings |
rotTrsJSONFile | ProSHADE_settings |
saveMask | ProSHADE_settings |
setAxisComparisonThreshold(proshade_double axThres) | ProSHADE_settings |
setAxisComparisonThresholdBehaviour(bool behav) | ProSHADE_settings |
setBandwidth(proshade_unsign band) | ProSHADE_settings |
setBicubicInterpolationSearch(bool bicubPeaks) | ProSHADE_settings |
setBoundsSpace(proshade_single boundsExSp) | ProSHADE_settings |
setBoundsThreshold(proshade_signed boundsThres) | ProSHADE_settings |
setCorrelationMasking(bool corMask) | ProSHADE_settings |
setDetectedSymmetry(proshade_double *sym) | ProSHADE_settings |
setEnergyLevelsComputation(bool enLevDesc) | ProSHADE_settings |
setEnLevShellWeight(proshade_double mPower) | ProSHADE_settings |
setExtraSpace(proshade_single exSpace) | ProSHADE_settings |
setGroupingSmoothingFactor(proshade_double smFact) | ProSHADE_settings |
setIntegrationOrder(proshade_unsign intOrd) | ProSHADE_settings |
setMapCentering(bool com) | ProSHADE_settings |
setMapInversion(bool mInv) | ProSHADE_settings |
setMapReboxing(bool reBx) | ProSHADE_settings |
setMapResolutionChange(bool mrChange) | ProSHADE_settings |
setMapResolutionChangeTriLinear(bool mrChange) | ProSHADE_settings |
setMaskBlurFactor(proshade_single blurFac) | ProSHADE_settings |
setMaskFilename(std::string mskFln) | ProSHADE_settings |
setMasking(bool mask) | ProSHADE_settings |
setMaskIQR(proshade_single noIQRs) | ProSHADE_settings |
setMaskSaving(bool savMsk) | ProSHADE_settings |
setMaxSymmetryFold(proshade_unsign maxFold) | ProSHADE_settings |
setMinimumMaskSize(proshade_single minMS) | ProSHADE_settings |
setMinimumPeakForAxis(proshade_double minSP) | ProSHADE_settings |
setMissingPeakThreshold(proshade_double mpThres) | ProSHADE_settings |
setNormalisation(bool normalise) | ProSHADE_settings |
setOutputFilename(std::string oFileName) | ProSHADE_settings |
setOverlayJsonFile(std::string filename) | ProSHADE_settings |
setOverlaySaveFile(std::string filename) | ProSHADE_settings |
setPDBBFactor(proshade_double newBF) | ProSHADE_settings |
setPeakNaiveNoIQR(proshade_double noIQRs) | ProSHADE_settings |
setPeakNeighboursNumber(proshade_unsign pkS) | ProSHADE_settings |
setPhaseUsage(bool phaseUsage) | ProSHADE_settings |
setProgressiveSphereMapping(bool progSphMap) | ProSHADE_settings |
setRecommendedFold(proshade_unsign val) | ProSHADE_settings |
setRecommendedSymmetry(std::string val) | ProSHADE_settings |
setRequestedFold(proshade_unsign val) | ProSHADE_settings |
setRequestedSymmetry(std::string val) | ProSHADE_settings |
setResolution(proshade_single resolution) | ProSHADE_settings |
setRotationFunctionComputation(bool rotfVal) | ProSHADE_settings |
setSameBoundaries(bool sameB) | ProSHADE_settings |
setSphereDistances(proshade_single sphDist) | ProSHADE_settings |
setSymmetryRotFunPeaks(bool rotFunPeaks) | ProSHADE_settings |
setTaylorSeriesCap(proshade_unsign tayCap) | ProSHADE_settings |
setTraceSigmaComputation(bool trSigVal) | ProSHADE_settings |
setTypicalNoiseSize(proshade_single typNoi) | ProSHADE_settings |
setVariablesLeftOnAuto(void) | ProSHADE_settings |
setVerbosity(proshade_signed verbosity) | ProSHADE_settings |
smoothingFactor | ProSHADE_settings |
symMissPeakThres | ProSHADE_settings |
task | ProSHADE_settings |
taylorSeriesCap | ProSHADE_settings |
useBiCubicInterpolationOnPeaks | ProSHADE_settings |
useCorrelationMasking | ProSHADE_settings |
usePeakSearchInRotationFunctionSpace | ProSHADE_settings |
usePhase | ProSHADE_settings |
useSameBounds | ProSHADE_settings |
verbose | ProSHADE_settings |
~ProSHADE_settings(void) | ProSHADE_settings |